<?php

/**
 * Good only works in WordPress 4.4 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.4-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

if ( ! function_exists( 'good_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 */
	function good_setup() {

		/**
		 * Make theme available for translation
		 * Translations can be filed in the /languages/ directory
		 * If you're building a theme based on good, use a find and replace
		 * to change 'good' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'good', get_template_directory() . '/languages' );

		/**
		 * Add default posts and comments RSS feed links to head
		 */
		add_theme_support( 'automatic-feed-links' );

		/**
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/**
		 * Enable support for Custom Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'     => 90,
			'width'      => 127,
			'flex-width' => true,
		) );

		/**
		 * Enable support for Post Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 450, 1000, true );

		/**
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/**
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
			'gallery',
			'status',
			'audio',
			'chat',
		) );

		/**
		 * This theme uses wp_nav_menu() in one location.
		 */
		register_nav_menus( array(
			'primary' => __( 'Primary Menu', 'good' ),
			'footer'  => __( 'Footer Menu', 'good' ),
		) );

		/**
		 * Adding styling to the editor
		 */
		add_editor_style( 'style-editor.css' );

		/**
		 * Remove Default CSS for gallery
		 */
		add_filter( 'use_default_gallery_style', '__return_false' );
	}
endif;

add_action( 'after_setup_theme', 'good_setup' );


/**
 * Sets the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function good_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'good_content_width', 720 );
}

add_action( 'after_setup_theme', 'good_content_width', 0 );


/**
 * Setup the WordPress core custom background feature.
 */
function good_register_custom_background() {

	add_theme_support( 'custom-background', apply_filters( 'good_custom_background_args', array(
		'default-color' => 'eeeeee',
	) ) );

}

add_action( 'after_setup_theme', 'good_register_custom_background' );


/**
 * Register widgetized area and update sidebar with default widgets
 */
function good_widgets_init() {
	register_sidebar( array(
		'name'            => __( 'Sidebar', 'good' ),
		'id'              => 'sidebar-1',
		'before_widget'   => '<aside id="%1$s" class="widget boxed %2$s">',
		'after_widget'    => '</aside>',
		'before_title'    => '<h5 class="widget-title"><span>',
		'after_title'     => '</span></h5>',
		'widget_id'       => '%1$s',
		'widget_position' => 'sidebar',
	) );

	register_sidebar( array(
		'name'            => __( 'Homepage Content', 'good' ),
		'id'              => 'homepage-content-widgets',
		'before_widget'   => '<div id="%1$s" class="widget homepage-widget %2$s">',
		'after_widget'    => '</div>',
		'before_title'    => '<h5 class="widget-title"><span>',
		'after_title'     => '</span></h5>',
		'widget_id'       => '%1$s',
		'widget_position' => 'main-content',
	) );

	register_sidebar( array(
		'name'            => __( 'Header Ad', 'good' ),
		'id'              => 'header-ad',
		'before_widget'   => '<div id="%1$s" class="widget header-widget %2$s">',
		'after_widget'    => '</div>',
		'before_title'    => '<h5 class="widget-title"><span>',
		'after_title'     => '</span></h5>',
		'widget_id'       => '%1$s',
		'widget_position' => 'main-content',
	) );


	$list_pages = get_posts( array(
		'post_type'  => 'page',
		'meta_key'   => '_wp_page_template',
		'meta_value' => 'page-templates/widgetized-page.php',
	) );

	foreach ( $list_pages as $w_page ) {
		register_sidebar( array(
			'name'            => $w_page->post_title,
			'id'              => $w_page->post_name,
			'before_widget'   => '<div id="%1$s" class="widget homepage-widget %2$s">',
			'after_widget'    => '</div>',
			'before_title'    => '<h4 class="widget-title"><span>',
			'after_title'     => '</span></h4>',
			'widget_id'       => '%1$s',
			'widget_position' => 'main-content',
		) );
	}
}

add_action( 'widgets_init', 'good_widgets_init' );


/**
 * Registers Widgets
 */
function good_register_widgets() {
	require( get_template_directory() . '/inc/widgets/recent_comments.php' );
	require( get_template_directory() . '/inc/widgets/recent_posts.php' );

	register_widget( 'Good_Widget_Recent_Comments' );
	register_widget( 'Good_Widget_Recent_Posts' );
}

add_action( 'widgets_init', 'good_register_widgets' );


/**
 * Enqueue scripts and styles
 */
function good_scripts() {
	wp_enqueue_style( 'good-style', get_stylesheet_uri() );

	// Conditionally Load Scripts
	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/vendor/html5shiv.min.js', array(), '20160705' );
	wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'selectivizr', get_template_directory_uri() . '/js/vendor/selectivizr.min.js', array(), '20160705' );
	wp_script_add_data( 'selectivizr', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/vendor/respond.min.js', array(), '20160705' );
	wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js/vendor/jquery.fitvids.min.js', array( 'jquery' ), '20160705', true );
	
	wp_enqueue_script( 'good-script', get_template_directory_uri() . '/js/script.js', array( 'jquery', 'jquery-fitvids', ), '20120206', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'good-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}

add_action( 'wp_enqueue_scripts', 'good_scripts' );


/**
 * Manage font to load based on the customizer setting
 */
function good_load_font() {

	$websafe_lib = array(

		'Arial__400,700',
		'Arial_Black__400,700',
		'Book_Antiqua__400,700',
		'Comic_Sans_MS__400,700',
		'Courier_New__400,700',
		'Geneva__400,700',
		'Georgia__400,700',
		'Helvetica__400,700',
		'Impact__400,700',
		'Lucida_Console__400,700',
		'Lucida_Grande__400,700',
		'Lucida_Sans_Unicode__400,700',
		'Monaco__400,700',
		'New_York__400,700',
		'Palatino_Lynotype__400,700',
		'Tahoma__400,700',
		'Times_New_Roman__400,700',
		'Trebuchet_MS__400,700',
		'Verdana__400,700',

	);

	$default_font = array(
		'body_font'         => 'Lora__400,400italic,700,700italic',
		'heading_font'      => 'Source_Sans_Pro__400',
		'menu_font'         => 'Lora__400,400italic,700,700italic',
		'meta_font'         => 'Lora__400,400italic,700,700italic',
		'widget_title_font' => 'Source_Sans_Pro__400',
	);

	$added = array();

	foreach ( $default_font as $section => $default ) {

		if ( ! ( $font_to_load = get_theme_mod( $section ) ) ) {
			$font_to_load = $default;
		}

		if ( ! in_array( $font_to_load, $websafe_lib ) && ! in_array( $font_to_load, $added ) ) {
			$added[]      = $font_to_load;
			$font_to_load = str_replace( '__', ':', $font_to_load );
			$font_id      = substr( $font_to_load, 0, strpos( $font_to_load, ':' ) );
			$font_to_load = str_replace( '_', '+', $font_to_load );
			$font_url     = 'http://fonts.googleapis.com/css?family=' . $font_to_load;

			wp_enqueue_style( $font_id, $font_url );
		}
	}

}

add_action( 'wp_enqueue_scripts', 'good_load_font' );


/**
 * Apply font to css based on the customizer setting
 */
function good_fonts_css() {

	$echo = '';
	if ( $font_to_load = get_theme_mod( 'body_font' ) ) {
		$echo .= 'body, .no-heading-style, input[type=text], input[type=email], input[type=password], textarea {';
		$echo .= 'font-family : "' . str_replace( '_', ' ', substr( $font_to_load, 0, strpos( $font_to_load, '__' ) ) ) . '"; ';
		$echo .= '}';
	}

	if ( $font_to_load = get_theme_mod( 'heading_font' ) ) {
		$echo .= 'h1, .h1, h2, .h2, h3, .h3, h4, .h4, h5, .h5, h6, .h6 {';
		$echo .= 'font-family : "' . str_replace( '_', ' ', substr( $font_to_load, 0, strpos( $font_to_load, '__' ) ) ) . '"; ';
		$echo .= '}';
	}

	if ( $font_to_load = get_theme_mod( 'menu_font' ) ) {
		$echo .= '.secondary-navigation > div > ul > li > a, .section-title, #reply-title, .widget-title, button, html input[type="button"], input[type="reset"], input[type="submit"] {';
		$echo .= 'font-family : "' . str_replace( '_', ' ', substr( $font_to_load, 0, strpos( $font_to_load, '__' ) ) ) . '"; ';
		$echo .= '}';
	}

	if ( $echo ) {
		$css = '
			/* Custom Fonts CSS */
			%1$s
		';

		wp_add_inline_style( 'good-style', sprintf(
			$css,
			strip_tags( $echo )
		) );
	}
}

add_action( 'wp_enqueue_scripts', 'good_fonts_css' );


/**
 * Get theme option set by customizer
 *
 * @param $name
 * @param $default
 *
 * @return string
 */
function good_get_option( $name, $default = false ) {

	return get_theme_mod( $name, $default );

}


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions
 */
require get_template_directory() . '/inc/customizer-helper.php';
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
